@@ -2,8 +2,6 @@ import traceback
 
 import pandas as pd
 import pytest
-from pytest_html.html_report import HTMLReport
-
 from .drivers.browsers import browser_os_name_conf
 from .conf.rwd.Website import base_url_conf
 from .utils import html_report_conf
@@ -12,6 +10,8 @@ from .pages.mobile_zero_page import Mobile_Zero_Page
 from datetime import datetime
 import os, pytest, sys, time
 from .conf import product_list
+import pytest_html
+from pytest_html import extras
 
 
 @pytest.fixture
@@ -57,7 +57,11 @@ def test_obj(base_url, browser, browser_version, os_version, os_name, remote_fla
         test_obj.start_time = int(time.time())
 
         yield test_obj
+
         # Teardown
+        # gif_file = test_obj.write_test_summary()
+        # extra.append(extras.image(gif_file, mime_type='image/gif', extension='gif'))
+        #
         test_obj.log_obj.remove_logger()  # Remove original log handlers
         test_obj.wait(3)
         test_obj.teardown()
@@ -67,6 +71,15 @@ def test_obj(base_url, browser, browser_version, os_version, os_name, remote_fla
         print("Python says:%s" % str(e))
         traceback.print_exc()
 
+    # finally:
+    #     if not test_obj.calling_module:
+    #         test_obj.calling_module = testname
+    #     gif_file = test_obj.write_test_summary()
+    #     extra.append(extras.image(gif_file, mime_type='image/gif', extension='gif'))
+    #     test_obj.log_obj.remove_logger()  # Remove original log handlers
+    #     test_obj.wait(3)
+    #     test_obj.teardown()
+
 
 @pytest.fixture
 def test_mobile_obj(mobile_os_name, mobile_os_version, device_name, app_package, app_activity, remote_flag, device_flag,
@@ -172,12 +185,14 @@ def non_breakable(request):
 def cases(request, product, testID):
     name = request.config.getoption("--xlsx")
     sheet = "Context"
-    df = pd.read_excel("././conf/web/" + product + '/' + name, sheet_name=sheet, dtype=str, usecols=lambda x: 'Remark' not in x)
+    df = pd.read_excel("././conf/web/" + product + '/' + name, sheet_name=sheet, dtype=str,
+                       usecols=lambda x: 'Remark' not in x)
     df = df.fillna('')
     row = df.index[df['testID'] == testID].tolist()
     data = (df.loc[row[0]])
     return data
 
+
 @pytest.fixture
 def testrail_flag(request):
     "pytest fixture for test rail flag"
@@ -223,10 +238,6 @@ def pytest_configure(config):
     if html_report_conf.gen_report:
         config.option.htmlpath = path
 
-    if not hasattr(config, "pluginmanager"):
-        return
-    config.pluginmanager.register(HTMLReport(config, path))
-
 
 def pytest_addoption(parser):
     "Method to add the option to ini."
@@ -564,6 +575,23 @@ def base_url(request):
         print("Python says:%s" % str(e))
 
 
+# @pytest.fixture
+# def extra(pytestconfig):
+#     """Add details to the HTML reports.
+#
+#     .. code-block:: python
+#
+#         import pytest_html
+#
+#
+#         def test_foo(extra):
+#             extra.append(pytest_html.extras.url("http://www.example.com/"))
+#     """
+#     pytestconfig.extras = []
+#     yield pytestconfig.extras
+#     del pytestconfig.extras[:]
+
+
 @pytest.fixture
 def api_url(request):
     "pytest fixture for base url"
